@@ -73,13 +73,11 @@ u_int32_t check_mounted(char *filename) {
 	}
 	
 	while ((mnt = getmntent(fd)) != NULL) {
-		if (realpath(mnt->mnt_fsname, rp_mnt_fsname) == NULL) {
-			myerror("Unable to get realpath!");
-			return -1;
-		}
-		if (strcmp(rp_mnt_fsname, rp_filename) == 0) {
-			ret = 1;
-			break;
+		if (realpath(mnt->mnt_fsname, rp_mnt_fsname) != NULL) {
+			if (strcmp(rp_mnt_fsname, rp_filename) == 0) {
+				ret = 1;
+				break;
+			}
 		}
 	}
 	
@@ -586,7 +584,7 @@ int32_t sort_fs(char *filename) {
 		// so sort it like all other directories
 		infomsg("File system: FAT32.\n\n");
 		if (sortClusterChain(fd, &bs, SwapInt32(bs.FATxx.FAT32.BS_RootClus), "/") == -1) {
-			myerror("Failed to sort cluster chain!");
+			myerror("Failed to sort first cluster chain!");
 			return -1;
 		}
 	} else {
